@@ -1,4 +1,9 @@
-## Copyright (C) 2004-2018 David Bateman and Andy Adler
+########################################################################
+##
+## Copyright (C) 2004-2022 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
 ##
 ## This file is part of Octave.
 ##
@@ -15,6 +20,8 @@
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
 ## <https://www.gnu.org/licenses/>.
+##
+########################################################################
 
 ## -*- texinfo -*-
 ## @deftypefn {} {@var{r} =} spones (@var{S})
@@ -26,7 +33,7 @@
 
 function r = spones (S)
 
-  if (nargin != 1)
+  if (nargin < 1)
     print_usage ();
   endif
 
